@@ -9,7 +9,7 @@ OC.L10N.register(
     "Delete" : "Smazat",
     "Rename" : "Přejmenovat",
     "Share with users or groups" : "Sdílet suživateli nebo skupinami",
-    "can edit" : "Může upravovat",
+    "can edit" : "může upravovat",
     "Close" : "Zavřít",
     "Enabled" : "Zapnuto",
     "Disabled" : "Vypnuto",
@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Název adresáře kontaktů",
     "Only these special characters are allowed: -_.!?#|()" : "Jsou povoleny pouze tyto speciální znaky:  -_.!?#|()",
     "Address book could not be created." : "Adresář se nepodařilo vytvořit.",
+    "Upload new image" : "Nahrát nový obrázek",
     "The selected image is too big (max 1MB)" : "Zvolený obrázek je příliš velký (max 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Tento kontakt je poškozen a byl obnoven. Prosím zkontrolujete data a proveďte uložení aby byly změny trvalé.",
     "No contacts in here" : "Nejsou zde žádné kontakty",
@@ -98,12 +99,16 @@ OC.L10N.register(
     "Relative" : "Příbuzný",
     "Friend" : "Přítel",
     "Colleague" : "Kolega",
-    "Manager" : "Manažer",
+    "Manager" : "Nadřízený",
     "Assistant" : "Asistent",
+    "Related" : "Související",
+    "Contact" : "Kontakt",
+    "Emergency" : "Nouze",
+    "Co-worker" : "Spolupracovník",
     "Gender" : "Pohlaví",
     "Female" : "Žena",
     "Male" : "Muž",
     "Details" : "Detaily",
     "Settings" : "Nastavení"
 },
-"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
+"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
