@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Name des Adressbuchs",
     "Only these special characters are allowed: -_.!?#|()" : "Es sind nur die folgenden Sonderzeichen erlaubt: -_.!?#|()",
     "Address book could not be created." : "Adressbuch konnte nicht erstellt werden.",
+    "Upload new image" : "Neues Bild hochladen",
     "The selected image is too big (max 1MB)" : "Das ausgewählte Bild ist zu groß (max. 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Diese Karte ist beschädigt und wurde repariert. Überprüfen Sie die Daten. Speichern Sie um die Änderungen dauerhaft zu übernehmen.",
     "No contacts in here" : "Keine Kontakte vorhanden",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Pager Arbeit",
     "Social network" : "Soziales Netzwerk",
     "Relationship" : "Beziehung",
+    "Specify a relationship between you and the entity represented by this vCard." : "Wählen Sie die Beziehungsart zwischen Ihnen und der Einheit, welche diese vCard darstellt.",
     "Spouse" : "Partner",
     "Child" : "Kind",
     "Mother" : "Mutter",
@@ -102,10 +104,17 @@ OC.L10N.register(
     "Colleague" : "Kollege",
     "Manager" : "Geschäftsleiter",
     "Assistant" : "Assistent",
+    "Related" : "Verwandt",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Wählen Sie die Beziehungsart zwischen einer Einheit und der Einheit, welche diese vCard darstellt.",
+    "Contact" : "Kontakt",
+    "Agent" : "Vertreter",
+    "Emergency" : "Notfall",
+    "Co-worker" : "Kollege",
     "Gender" : "Geschlecht",
     "Female" : "Weiblich",
     "Male" : "Männlich",
     "Details" : "Details",
+    "A contacts app for Nextcloud" : "Eine Adressbuch-App für Nextcloud",
     "Settings" : "Einstellungen"
 },
 "nplurals=2; plural=(n != 1);");
