@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Address book name",
     "Only these special characters are allowed: -_.!?#|()" : "Only these special characters are allowed: -_.!?#|()",
     "Address book could not be created." : "Address book could not be created.",
+    "Upload new image" : "Upload new image",
     "The selected image is too big (max 1MB)" : "The selected image is too big (max 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent.",
     "No contacts in here" : "No contacts in here",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Work pager",
     "Social network" : "Social network",
     "Relationship" : "Relationship",
+    "Specify a relationship between you and the entity represented by this vCard." : "Specify a relationship between you and the entity represented by this vCard.",
     "Spouse" : "Spouse",
     "Child" : "Child",
     "Mother" : "Mother",
@@ -102,6 +104,12 @@ OC.L10N.register(
     "Colleague" : "Colleague",
     "Manager" : "Manager",
     "Assistant" : "Assistant",
+    "Related" : "Related",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Specify a relationship between another entity and the entity represented by this vCard.",
+    "Contact" : "Contact",
+    "Agent" : "Agent",
+    "Emergency" : "Emergency",
+    "Co-worker" : "Co-worker",
     "Gender" : "Gender",
     "Female" : "Female",
     "Male" : "Male",
