@@ -93,4 +93,4 @@ OC.L10N.register(
     "Details" : "جزئیات",
     "Settings" : "تنظیمات"
 },
-"nplurals=1; plural=0;");
+"nplurals=2; plural=(n > 1);");
