@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Osoitekirjan nimi",
     "Only these special characters are allowed: -_.!?#|()" : "Vain seuraavat erikoismerkit ovat sallittuja: -_.!?#|()",
     "Address book could not be created." : "Osoitekirjaa ei voitu luoda.",
+    "Upload new image" : "Lähetä uusi kuva",
     "The selected image is too big (max 1MB)" : "Valittu kuva on liian suuri kooltaan (enintään 1 Mt)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Tämä yhteystietokortti on vioittunut ja se on korjattu. Tarkista tiedot ja tallenna vahvistaaksesi muutokset pysyvästi.",
     "No contacts in here" : "Ei yhteytietoja",
@@ -101,6 +102,8 @@ OC.L10N.register(
     "Colleague" : "Työkaveri",
     "Manager" : "Esimies",
     "Assistant" : "Avustaja",
+    "Emergency" : "Hätä",
+    "Co-worker" : "Työkaveri",
     "Gender" : "Sukupuoli",
     "Female" : "Nainen",
     "Male" : "Mies",
