@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Nom du carnet d'adresses",
     "Only these special characters are allowed: -_.!?#|()" : "Seuls ces caractères spéciaux sont autorisés : -_.!?#|()",
     "Address book could not be created." : "Impossible de créer le carnet d'adresses.",
+    "Upload new image" : "Téléverser une nouvelle image",
     "The selected image is too big (max 1MB)" : "L'image sélectionnée est trop volumineuse (1 Mo max)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Cette carte est corrompue et a été corrigée. Veuillez vérifier les données et lancer une sauvegarde pour rendre les changements définitifs.",
     "No contacts in here" : "Aucun contact",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Bip professionnel",
     "Social network" : "Réseau social",
     "Relationship" : "Relation",
+    "Specify a relationship between you and the entity represented by this vCard." : "Indiquez une relation entre vous et l'entité représentée par cette vCard.",
     "Spouse" : "Conjoint",
     "Child" : "Enfant",
     "Mother" : "Mère",
@@ -102,6 +104,12 @@ OC.L10N.register(
     "Colleague" : "Collègue",
     "Manager" : "Directeur",
     "Assistant" : "Assistant",
+    "Related" : "En relation",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Spécifiez une relation entre l'entité représentée par cette vCard et une autre entité.",
+    "Contact" : "Contact",
+    "Agent" : "Agent",
+    "Emergency" : "Urgence",
+    "Co-worker" : "Collaborateur",
     "Gender" : "Sexe",
     "Female" : "Féminin",
     "Male" : "Masculin",
