@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Heiti nafnaskrár",
     "Only these special characters are allowed: -_.!?#|()" : "Aðeins þessir sérstafir eru leyfðir: -_.!?#|()",
     "Address book could not be created." : "Tókst ekki að búa til nafnaskrá.",
+    "Upload new image" : "Senda inn nýja mynd",
     "The selected image is too big (max 1MB)" : "Valin mynd er of stór (hám. 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Þetta nafnspjald er skemmt en viðgerð hefur farið fram. Farðu vel yfir upplýsingarnar og vistaðu það síðan til að gera breytingarnar varanlegar.",
     "No contacts in here" : "Engir tengiliðir hér",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Vinnufriðþjófur",
     "Social network" : "Samfélagsnet",
     "Relationship" : "Vensl",
+    "Specify a relationship between you and the entity represented by this vCard." : "Tiltaktu venslin milli þín og þess aðila sem þetta vCard-nafnspjald stendur fyrir.",
     "Spouse" : "Maki",
     "Child" : "Barn",
     "Mother" : "Móðir",
@@ -102,6 +104,12 @@ OC.L10N.register(
     "Colleague" : "Samstarfsmaður",
     "Manager" : "Yfirmaður",
     "Assistant" : "Aðstoðarmaður",
+    "Related" : "Venslað",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Tiltaktu venslin milli annars aðila og þess aðila sem þetta vCard-nafnspjald stendur fyrir.",
+    "Contact" : "Tengiliður",
+    "Agent" : "Umboðsaðili",
+    "Emergency" : "Neyðartilfelli",
+    "Co-worker" : "Samstarfsmaður",
     "Gender" : "Kyn",
     "Female" : "Kona",
     "Male" : "Karl",
