@@ -11,6 +11,8 @@ OC.L10N.register(
     "Share with users or groups" : "Del med brukere eller grupper",
     "can edit" : "kan redigere",
     "Close" : "Lukk",
+    "Enabled" : "Aktiver",
+    "Disabled" : "Deaktiver",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikke støttet!",
     "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere",
@@ -31,6 +33,7 @@ OC.L10N.register(
     "Import into" : "Importer inn i",
     "Importing..." : "Importerer…",
     "Select your addressbook" : "Velg din adressebok",
+    "Import is disabled because no writable address book had been found." : "Import er deaktivert siden det ikke finnes noe adressebøker som er skrivbare",
     "No search result for {query}" : "Intet søkeresultat for {query}",
     "All contacts" : "Alle kontakter",
     "Post office box" : "Postboks",
@@ -49,14 +52,17 @@ OC.L10N.register(
     "New contact" : "Ny kontakt",
     "Not grouped" : "Ikke gruppert",
     "Sort by" : "Sorter etter",
+    "There is no address book available to create a contact." : "Det finnes ingen adressebok å legge til kontakt i.",
     "{addressbook} shared by {owner}" : "{addressbook} delt av {owner}",
     "Contact not found." : "Fant ikke kontakten.",
-    "You don't have permission to write to this addressbook." : "Du har ikke tilgang til å skrive i denne adresseboka.",
+    "You don't have permission to write to this addressbook." : "Du har ikke skrivetilgang til denne adresseboka.",
     "Contact could not be created." : "Kontakten kunne ikke opprettes",
     "No contacts in file. Only vCard files are allowed." : "Ingen kontakter i filen. Kun vCard filer er tillatt.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Kun vCard versjon 4.0 (RFC6350) eller versjon 3.0 (RFC2426) er støttet.",
+    "Contact could not be moved." : "Kontakten kunne ikke flyttes.",
     "Contact could not be saved." : "Kontakten kunne ikke lagres.",
-    "Waiting for the server to be ready..." : "Venter på at tjeneres skal bli klar...",
+    "Waiting for the server to be ready…" : "Venter på at tjeneres skal bli klar…",
+    "Importing…" : "Importerer…",
     "Display name" : "Visningsnavn",
     "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
@@ -74,11 +80,14 @@ OC.L10N.register(
     "Instant messaging" : "Direktemeldinger",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
+    "Work mobile" : "Arbeidstelefon",
     "Fax" : "Faks",
     "Fax home" : "Faks hjemme",
     "Fax work" : "Faks jobb",
     "Pager" : "Pager",
     "Voice" : "Svarer",
+    "Car" : "Bil",
+    "Work pager" : "Arbeidspersonsøker",
     "Social network" : "Sosialt nettverk",
     "Relationship" : "Forhold",
     "Spouse" : "Ektefelle",
