@@ -2,21 +2,21 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Contactes",
-    "Import" : "Importar",
     "Name" : "Nom",
     "Organization" : "Societat",
     "Title" : "Títol",
-    "Add field ..." : "Apondre un camp...",
-    "Add contact" : "Apondre un contacte",
     "All contacts" : "Totes los contactes",
-    "Not grouped" : "Pas gropats",
-    "Postal Code" : "Còdi postal",
+    "Postal code" : "Còde postal",
     "City" : "Vila",
     "State or province" : "Estat o region",
     "Country" : "País",
     "Address" : "Adreça",
     "(new group)" : "(grop novèl)",
+    "Last name" : "Nom",
+    "First name" : "Prenom",
+    "Additional names" : "Noms suplementaris",
     "New contact" : "Contacte novèl",
+    "Not grouped" : "Pas gropats",
     "Nickname" : "Escais",
     "Notes" : "Nòtas",
     "Website" : "Site web",
