@@ -11,22 +11,29 @@ OC.L10N.register(
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "can edit" : "poate edita",
     "Close" : "Închide",
+    "Enabled" : "Activat",
+    "Disabled" : "Dezactivat",
     "Copied!" : "S-a copiat!",
     "Not supported!" : "Nu este suportat!",
     "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
     "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
     "Address book name" : "Numele listă de contacte",
+    "Only these special characters are allowed: -_.!?#|()" : "Numai aceste caractere speciale sunt permise: -_.!?#|()",
+    "Address book could not be created." : "Lista  de contacte nu a putut fi creată.",
     "The selected image is too big (max 1MB)" : "Imaginea selectată este prea mare (maxim 1 MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Acest card este corupt și a fost reparat. Verifică datele și declanșează operațiunea de salvare pentru a face modificările permanente.",
     "No contacts in here" : "Niciun contact aici",
     "Name" : "Nume",
     "Organization" : "Organizație",
     "Title" : "Titlu",
+    "Add field …" : "Adaugă câmp ...",
     "Save changes" : "Salvează modificările",
     "Address book" : "Listă de contacte",
+    "Loading contacts …" : "Se încarcă contactele ...",
     "Import into" : "Importă în",
     "Importing..." : "Se importă...",
     "Select your addressbook" : "Selectează lista ta de contacte",
+    "Import is disabled because no writable address book had been found." : "Importul este dezactivat deoarece nu a fost găsită nicio listă de contacte.",
     "No search result for {query}" : "Niciun rezultat pentru {query}",
     "All contacts" : "Toate contactele",
     "Post office box" : "Oficiul poștal",
@@ -45,14 +52,17 @@ OC.L10N.register(
     "New contact" : "Contact nou ",
     "Not grouped" : "Negrupate",
     "Sort by" : "Sortează după",
+    "There is no address book available to create a contact." : "Nicio listă de contacte disponibilă pentru a crea un contact.",
     "{addressbook} shared by {owner}" : "{addressbook} partajat de {owner}",
     "Contact not found." : "Contactul nu a fost găsit.",
     "You don't have permission to write to this addressbook." : "Nu aveți dreptul de a scrie în această listă de contacte.",
     "Contact could not be created." : "Persoana de contact nu a putut fi creată.",
     "No contacts in file. Only vCard files are allowed." : "Nici un contact în fișier. Numai fișierele vCard sunt permise.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Numai VCard versiunea 4.0 (RFC6350) sau versiunea 3.0 (RFC2426) sunt suportate.",
+    "Contact could not be moved." : "Contactul nu a putut fi mutat.",
     "Contact could not be saved." : "Contactul nu a fost salvat.",
-    "Waiting for the server to be ready..." : "Se așteaptă ca serverul să fie disponibil...",
+    "Waiting for the server to be ready…" : "Se așteaptă ca serverul să fie disponibil...",
+    "Importing…" : "Se importă...",
     "Display name" : "Nume afișat",
     "Nickname" : "Pseudonim",
     "Detailed name" : "Nume detaliat",
@@ -70,11 +80,14 @@ OC.L10N.register(
     "Instant messaging" : "Mesagerie instantă",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
+    "Work mobile" : "Telefon serviciu",
     "Fax" : "Fax",
     "Fax home" : "Fax - acasă",
     "Fax work" : "Fax - serviciu",
     "Pager" : "Pager",
     "Voice" : "Voce",
+    "Car" : "Mașina",
+    "Work pager" : "Pager de serviciu",
     "Social network" : "Rețea socială",
     "Relationship" : "Legătură",
     "Spouse" : "Soție",
