@@ -20,18 +20,19 @@ OC.L10N.register(
     "Address book name" : "Название адресной книги",
     "Only these special characters are allowed: -_.!?#|()" : "Допустимы только следующие специальные символы: -_.!?#|()",
     "Address book could not be created." : "Не удалось создать адресную книгу.",
+    "Upload new image" : "Загрузить изображение",
     "The selected image is too big (max 1MB)" : "Выбранное изображение слишком велико (макс. 1 МБ)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Эта поврежденная карточка была исправлена. Проверьте данные и выберите «сохранить» для  сохранения изменений. ",
     "No contacts in here" : "Здесь нет контактов",
     "Name" : "имя, отчество и фамилия контакта",
     "Organization" : "Организация",
     "Title" : "Должность",
-    "Add field …" : "Добавить поле...",
+    "Add field …" : "Добавить поле…",
     "Save changes" : "Сохранить изменения",
     "Address book" : "Адресная книга",
     "Loading contacts …" : "Загрузка контактов…",
     "Import into" : "Импортировать в",
-    "Importing..." : "Производится импорт...",
+    "Importing..." : "Производится импорт…",
     "Select your addressbook" : "Выберите адресную книгу",
     "Import is disabled because no writable address book had been found." : "Возможность импорта отключена, т.к. отсутствуют адресные книги, в которые можно выполнить запись.",
     "No search result for {query}" : "По запросу {query} ничего не найдено",
@@ -61,8 +62,8 @@ OC.L10N.register(
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Поддерживается только формат vCard версии 4.0 (RFC6350) или версии 3.0 (RFC2426).",
     "Contact could not be moved." : "Контакт не может быть перемещён.",
     "Contact could not be saved." : "Контакт не может быть сохранён.",
-    "Waiting for the server to be ready…" : "Ожидание готовности сервера...",
-    "Importing…" : "Импортируется...",
+    "Waiting for the server to be ready…" : "Ожидание готовности сервера…",
+    "Importing…" : "Импортируется…",
     "Display name" : "Отображаемое имя",
     "Nickname" : "Псевдоним",
     "Detailed name" : "Подробное имя",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Рабочий пейджер",
     "Social network" : "Социальная сеть",
     "Relationship" : "Отношнения",
+    "Specify a relationship between you and the entity represented by this vCard." : "Указать отношения между собой и этим контактом.",
     "Spouse" : "Супруг",
     "Child" : "Ребёнок",
     "Mother" : "Мать",
@@ -102,6 +104,12 @@ OC.L10N.register(
     "Colleague" : "Коллега",
     "Manager" : "Руководитель",
     "Assistant" : "Помощник",
+    "Related" : "Связи",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Указать отношение между этим и другим контактом.",
+    "Contact" : "Контакт",
+    "Agent" : "Агент",
+    "Emergency" : "Экстренный случай",
+    "Co-worker" : "Коллега",
     "Gender" : "Пол",
     "Female" : "Женщина",
     "Male" : "Мужчина",
