@@ -20,12 +20,13 @@ OC.L10N.register(
     "Address book name" : "Názov adresára kontaktov",
     "Only these special characters are allowed: -_.!?#|()" : "Povolené sú len tieto špeciálne znaky: -_.!?#|()",
     "Address book could not be created." : "Adresár sa nepodarilo sa vytvoriť",
+    "Upload new image" : "Nahrať nový obrázok",
     "The selected image is too big (max 1MB)" : "Vybraný obrázok je príliš veľký (max 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Poškodená karta bola opravená. Skontrolujte prosím údaje a stlačte uložiť pre uplatnenie zmien. ",
     "No contacts in here" : "Nie sú tu žiadne kontakty",
     "Name" : "Názov",
     "Organization" : "Organizácia",
-    "Title" : "Názov",
+    "Title" : "Pracovná funkcia",
     "Add field …" : "Pridať pole ...",
     "Save changes" : "Uložiť zmeny",
     "Address book" : "Adresár",
@@ -39,7 +40,7 @@ OC.L10N.register(
     "Post office box" : "Poštová adresa",
     "Postal code" : "PSČ",
     "City" : "Mesto",
-    "State or province" : "Štát alebo oblasť",
+    "State or province" : "Kraj alebo oblasť",
     "Country" : "Krajina",
     "Address" : "Adresa",
     "(new group)" : "(nová skupina)",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Pracovný pager",
     "Social network" : "Sociálna sieť",
     "Relationship" : "Vzťah",
+    "Specify a relationship between you and the entity represented by this vCard." : "Vzťah medzi entitou reprezentovanou touto vCard vizitkou a Vami.",
     "Spouse" : "Partner/ka",
     "Child" : "Dieťa",
     "Mother" : "Matka",
@@ -102,10 +104,16 @@ OC.L10N.register(
     "Colleague" : "Kolega",
     "Manager" : "Manažér",
     "Assistant" : "Asistent",
+    "Related" : "Súvisiace",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Vzťah medzi entitou reprezentovanou touto vCard vizitkou a ďalšou entitou.",
+    "Contact" : "Kontakt",
+    "Agent" : "Agent",
+    "Emergency" : "Núdzový kontakt",
+    "Co-worker" : "Spolupracovník",
     "Gender" : "Pohlavie",
     "Female" : "Žena",
     "Male" : "Muž",
     "Details" : "Podrobnosti",
     "Settings" : "Nastavenia"
 },
-"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
+"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
