@@ -11,19 +11,29 @@ OC.L10N.register(
     "Share with users or groups" : "Deli z uporabniki ali skupinami",
     "can edit" : "lahko ureja",
     "Close" : "Zapri",
+    "Enabled" : "Omogočeno",
+    "Disabled" : "Onemogočeno",
     "Copied!" : "Kopirano!",
     "Not supported!" : "Ni podprto!",
     "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
     "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
     "Address book name" : "Ime imenika",
+    "Only these special characters are allowed: -_.!?#|()" : "Dovoljeni so le sledeči posebni znaki: -_.!?#|()",
+    "Address book could not be created." : "Imenika ni mogoče ustvariti.",
     "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Ta kartica je počkodovana in je bila popravljena. Preveri podatke in shrani, da bodo spremembe trajne.",
     "No contacts in here" : "Ni dodanega nobenega stika!",
     "Name" : "Ime",
     "Organization" : "Ustanova",
     "Title" : "Naziv/funkcija",
+    "Add field …" : "Dodaj polje",
     "Save changes" : "Shrani spremembe",
     "Address book" : "Imenik",
+    "Loading contacts …" : "Nalaganje stikov ...",
+    "Import into" : "Uvozi v",
+    "Importing..." : "Uvažanje ...",
+    "Select your addressbook" : "Izberi imenik",
+    "Import is disabled because no writable address book had been found." : "Uvoz je onemogočen! Ni mogoče najti zapisljivega imenika.",
     "No search result for {query}" : "Ni zadetkov iskanja za {query}",
     "All contacts" : "Vsi stiki",
     "Post office box" : "Poštni predal",
@@ -38,15 +48,21 @@ OC.L10N.register(
     "Additional names" : "Druga imena",
     "Prefix" : "Predpona",
     "Suffix" : "Pripona",
+    "Importing into" : "Uvažanje informacij",
     "New contact" : "Nov stik",
     "Not grouped" : "Brez skupine",
     "Sort by" : "Uredi po",
+    "There is no address book available to create a contact." : "Za ustvarjanje stika ni na voljo nobenega imenika",
     "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
     "Contact not found." : "Stika ne najdem.",
+    "You don't have permission to write to this addressbook." : "Nimate dovoljenja za zapisovanje v imenik",
     "Contact could not be created." : "Stika ni mogoče ustvariti.",
     "No contacts in file. Only vCard files are allowed." : "V datoteki ni stikov. Dovoljene so samo vCard datoteke.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podpiramo samo vCard verzije 4.0 (RFC6350) ali verzije 3.0 (RFC2426).",
+    "Contact could not be moved." : "Stika ni mogoče premakniti",
     "Contact could not be saved." : "Stikov ne morem shraniti.",
+    "Waiting for the server to be ready…" : "Čakanje na strežnik ...",
+    "Importing…" : "Uvažanje",
     "Display name" : "Prikaži ime",
     "Nickname" : "Vzdevek",
     "Detailed name" : "Podrobno ime",
@@ -64,12 +80,31 @@ OC.L10N.register(
     "Instant messaging" : "Hipno sporočanje",
     "Phone" : "Telefon",
     "Mobile" : "Mobilni telefon",
+    "Work mobile" : "Službeni mobilni telefon",
     "Fax" : "Faks",
     "Fax home" : "Domači faks",
     "Fax work" : "Službeni faks",
     "Pager" : "Pozivnik",
     "Voice" : "Glas",
+    "Car" : "Avto",
+    "Work pager" : "Službeni pager",
     "Social network" : "Družbeno omrežje",
+    "Relationship" : "Razmerje",
+    "Spouse" : "Partner",
+    "Child" : "Otrok",
+    "Mother" : "Mati",
+    "Father" : "Oče",
+    "Parent" : "Starš",
+    "Brother" : "Brat",
+    "Sister" : "Sestra",
+    "Relative" : "Sorodnik",
+    "Friend" : "Prijatelj",
+    "Colleague" : "kolega",
+    "Manager" : "Vodja",
+    "Assistant" : "Asistent",
+    "Gender" : "Spol",
+    "Female" : "Ženska",
+    "Male" : "Moški",
     "Details" : "Podrobnosti",
     "Settings" : "Nastavitve"
 },
