@@ -20,6 +20,7 @@ OC.L10N.register(
     "Address book name" : "Име адресара",
     "Only these special characters are allowed: -_.!?#|()" : "Само ови специјални карактери су дозвољени: -_.!?#|()",
     "Address book could not be created." : "Адресар не може да се креира.",
+    "Upload new image" : "Отпремите нову слику",
     "The selected image is too big (max 1MB)" : "Изабрана слика је превелика (макс 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Овај контакт је оштећен и сад је поправљен. Проверите податке и снимите га ако желите да запамтите ове измене.",
     "No contacts in here" : "Овде нема контаката",
@@ -90,6 +91,7 @@ OC.L10N.register(
     "Work pager" : "Пословни пејџер",
     "Social network" : "Социјална мрежа",
     "Relationship" : "Однос",
+    "Specify a relationship between you and the entity represented by this vCard." : "Одредите везу између Вас и ентитета представљеног овим vCard-ом.",
     "Spouse" : "Супруга",
     "Child" : "Дете",
     "Mother" : "Мајка",
@@ -102,10 +104,17 @@ OC.L10N.register(
     "Colleague" : "Колега",
     "Manager" : "Менаџер",
     "Assistant" : "Асистент",
+    "Related" : "У релацији",
+    "Specify a relationship between another entity and the entity represented by this vCard." : "Одредите везу између другог ентитета и ентитета представљеног овим vCard-ом.",
+    "Contact" : "Контакт",
+    "Agent" : "Агент",
+    "Emergency" : "Хитни број",
+    "Co-worker" : "Колега",
     "Gender" : "Пол",
     "Female" : "Женски",
     "Male" : "Мушки",
     "Details" : "Детаљи",
+    "A contacts app for Nextcloud" : "Некстклауд апликација за контакте",
     "Settings" : "Поставке"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
